"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SqlCompletionProvider = void 0;
/******************************************************************************
 * Copyright 2022-2023 TypeFox GmbH
 * This program and the accompanying materials are made available under the
 * terms of the MIT License, which is available in the project root.
 ******************************************************************************/
const langium_1 = require("langium");
const ast_1 = require("./generated/ast");
const sql_data_types_1 = require("./sql-data-types");
const vscode_languageserver_1 = require("vscode-languageserver");
const sql_type_utilities_1 = require("./sql-type-utilities");
class SqlCompletionProvider extends langium_1.DefaultCompletionProvider {
    constructor(services) {
        super(services);
        this.dataTypes = services.dialect.dataTypes.allTypes();
    }
    getCompletion(document, params) {
        return super.getCompletion(document, params);
    }
    completionFor(context, next, acceptor) {
        var _a;
        if ((0, ast_1.isDataType)(context.node) && next.property === 'dataTypeNames') {
            this.completeWithDataTypes(acceptor);
        }
        else if ((0, ast_1.isSimpleSelectStatement)(context.node) && next.type === 'SelectElements') {
            const columnDescriptors = (0, sql_type_utilities_1.getColumnCandidatesForSelectTableExpression)(context.node.$container);
            for (const columnDescriptor of columnDescriptors) {
                const text = (_a = columnDescriptor.name) !== null && _a !== void 0 ? _a : ((0, langium_1.isNamed)(columnDescriptor.node) ? columnDescriptor.node.name : undefined);
                acceptor({
                    kind: vscode_languageserver_1.CompletionItemKind.Field,
                    label: text,
                    insertText: text,
                });
            }
        }
        return super.completionFor(context, next, acceptor);
    }
    completeWithDataTypes(acceptor) {
        for (const dataType of this.dataTypes) {
            acceptor({
                label: (0, sql_data_types_1.toString)(dataType),
                kind: vscode_languageserver_1.CompletionItemKind.Class,
                insertText: (0, sql_data_types_1.toString)(dataType),
            });
        }
    }
}
exports.SqlCompletionProvider = SqlCompletionProvider;
//# sourceMappingURL=sql-completion-provider.js.map