import { AST as ast } from "./index";
export type TypeString = string;
export interface DialectTypeList<T> {
    strings: T[];
    integers: T[];
    reals: T[];
    dateTimes: T[];
    booleans: T[];
    blobs: T[];
    enums: T[];
}
export interface DataTypeArgument {
    type: 'string' | 'real' | 'integer' | 'size';
    optional: boolean;
}
export interface DataTypeDefinition {
    names: string[];
    arguments: DataTypeArgument[];
}
export declare function toString(dataType: DataTypeDefinition): string;
export declare function isCompatibleWithDefinition(ast: ast.DataType, required: DataTypeDefinition): boolean;
export declare function parseRequiredType(str: TypeString): DataTypeDefinition;
export declare class DialectTypes {
    private readonly types;
    constructor(types: DialectTypeList<TypeString>);
    isStringDataType(dataType: ast.DataType): boolean;
    isIntegerDataType(dataType: ast.DataType): boolean;
    isRealDataType(dataType: ast.DataType): boolean;
    isDateTimeDataType(dataType: ast.DataType): boolean;
    isBooleanDataType(dataType: ast.DataType): boolean;
    isBlobDataType(dataType: ast.DataType): boolean;
    isEnumDataType(dataType: ast.DataType): boolean;
    allTypes(): DataTypeDefinition[];
}
export declare function typesExtend<T>(a: DialectTypeList<T>, b: DialectTypeList<T>): DialectTypeList<T>;
