/******************************************************************************
 * Copyright 2022-2023 TypeFox GmbH
 * This program and the accompanying materials are made available under the
 * terms of the MIT License, which is available in the project root.
 ******************************************************************************/
import { AstNode, ValidationAcceptor } from "langium";
import * as ast from "./generated/ast";
import { TypeDescriptor } from "./sql-type-descriptors";
import { BinaryOperator, UnaryOperator } from "./sql-type-operators";
type SqlErrorReporter<T extends AstNode, P> = {
    (node: T, props: P, accept: ValidationAcceptor): void;
    Code: string;
};
interface Nameable {
    name: string;
}
interface NumericValue {
    value: number;
}
export declare const ReportAs: {
    DuplicatedVariableName: SqlErrorReporter<ast.SourceItem, Nameable>;
    NumericValueIsNotInteger: SqlErrorReporter<ast.NumberLiteral, NumericValue>;
    BinaryOperatorNotDefinedForGivenExpressions: SqlErrorReporter<ast.BinaryExpression, BinaryOperatorMismatch>;
    UnaryOperatorNotDefinedForGivenExpression: SqlErrorReporter<ast.UnaryExpression, UnaryOperatorMismatch>;
    ExpressionMustReturnABoolean: SqlErrorReporter<ast.Expression, TypeDescriptor>;
    AllStarSelectionRequiresTableSources: SqlErrorReporter<ast.SimpleSelectStatement, {}>;
    TableDefinitionRequiresAtLeastOneColumn: SqlErrorReporter<ast.GlobalReference, {}>;
    SubQueriesWithinSelectStatementsMustHaveExactlyOneColumn: SqlErrorReporter<ast.SubQueryExpression, {}>;
    CannotDeriveTypeOfExpression: SqlErrorReporter<ast.Expression, {}>;
    TableOperationUsesTablesWithDifferentColumnCounts: SqlErrorReporter<ast.BinaryTableExpression, {}>;
    TableOperationUsesTablesWithDifferentColumnTypes: SqlErrorReporter<ast.BinaryTableExpression, {
        columnIndex: number;
    }>;
    IncorrectGlobalReferenceTarget: SqlErrorReporter<ast.GlobalReference, {
        expected: string;
        received: string;
    }>;
    UnknownDataType: SqlErrorReporter<ast.DataType, {
        dataType: ast.DataType;
    }>;
};
export interface BinaryOperatorMismatch {
    op: BinaryOperator;
    left: TypeDescriptor;
    right: TypeDescriptor;
}
export interface UnaryOperatorMismatch {
    op: UnaryOperator;
    operand: TypeDescriptor;
}
export {};
