"use strict";
/******************************************************************************
 * Copyright 2022-2023 TypeFox GmbH
 * This program and the accompanying materials are made available under the
 * terms of the MIT License, which is available in the project root.
 ******************************************************************************/
Object.defineProperty(exports, "__esModule", { value: true });
exports.ReportAs = void 0;
class SqlErrorFactory {
    static create(code, severity, messageGenerator, diagnosticGenerator) {
        const reporter = ((node, props, accept) => {
            accept(severity, messageGenerator(props), ((node) => {
                const info = diagnosticGenerator(node);
                info.code = code;
                return info;
            })(node));
        });
        reporter.Code = code;
        return reporter;
    }
}
exports.ReportAs = {
    DuplicatedVariableName: SqlErrorFactory.create("SQL00001", "error", ({ name }) => `Duplicated variable name '${name}'.`, (node) => ({ node, property: "name" })),
    NumericValueIsNotInteger: SqlErrorFactory.create("SQL00002", "error", ({ value }) => `Value '${value}' is not an integer.`, (node) => ({ node, property: "value" })),
    BinaryOperatorNotDefinedForGivenExpressions: SqlErrorFactory.create("SQL00003", "error", ({ op, left, right }) => `Binary operator '${op}' is not defined for ('${left.discriminator}', '${right.discriminator}').`, (node) => ({ node, property: "operator" })),
    UnaryOperatorNotDefinedForGivenExpression: SqlErrorFactory.create("SQL00004", "error", ({ op, operand }) => `Unary operator '${op}' is not defined for '${operand.discriminator}'.`, (node) => ({ node, property: "operator" })),
    ExpressionMustReturnABoolean: SqlErrorFactory.create("SQL00005", "error", (operand) => `Expression must return a boolean, not a '${operand.discriminator}'.`, (node) => ({ node })),
    AllStarSelectionRequiresTableSources: SqlErrorFactory.create("SQL00006", "error", () => `All-star selection requires table sources (FROM is missing).`, (node) => ({ node })),
    TableDefinitionRequiresAtLeastOneColumn: SqlErrorFactory.create("SQL00007", "error", () => `Table definition requires at least one column.`, (node) => ({ node, property: "element" })),
    SubQueriesWithinSelectStatementsMustHaveExactlyOneColumn: SqlErrorFactory.create("SQL00008", "error", () => `Sub queries within select statements must have exactly one column.`, (node) => ({ node, property: "subQuery" })),
    CannotDeriveTypeOfExpression: SqlErrorFactory.create("SQL00009", "error", () => `Unable to derive the type of the expression.`, (node) => ({ node })),
    TableOperationUsesTablesWithDifferentColumnCounts: SqlErrorFactory.create("SQL00010", "error", () => `This operation uses tables with different amounts of columns, which is forbidden. Please add the missing columns.`, (node) => ({ node, property: 'operator' })),
    TableOperationUsesTablesWithDifferentColumnTypes: SqlErrorFactory.create("SQL00011", "error", ({ columnIndex }) => `This operation uses tables with different columns types! Compare the columns at index ${columnIndex}. They are not convertable to each other.`, (node) => ({ node, property: 'operator' })),
    IncorrectGlobalReferenceTarget: SqlErrorFactory.create("SQL00012", "error", ({ expected, received }) => `Expected definition of type '${expected}' but received '${received}'.`, (node) => ({ node, property: 'element' })),
    UnknownDataType: SqlErrorFactory.create("SQL00013", "error", ({ dataType }) => `Unknown data type '${dataType.dataTypeNames.join(' ')}(${dataType.arguments.map(dt => dt.value).join(', ')})'.`, (node) => ({ node }))
};
//# sourceMappingURL=sql-error-codes.js.map