/******************************************************************************
 * Copyright 2022-2023 TypeFox GmbH
 * This program and the accompanying materials are made available under the
 * terms of the MIT License, which is available in the project root.
 ******************************************************************************/
import { DeepPartial, DefaultSharedModuleContext, LangiumServices, LangiumSharedServices, Module } from "langium";
import { SqlContainerManager } from "./sql-container-manager";
import { DialectTypes } from "./sql-data-types";
import { TypeComputer } from "./sql-type-computation";
import { SqlValidator } from "./sql-validator";
import { SqlWorkspaceManager } from "./sql-workspace-manager";
/**
 * Declaration of custom services - add your own service classes here.
 */
export type SqlAddedServices = {
    dialect: {
        dataTypes: DialectTypes;
        typeComputer: TypeComputer;
    };
    validation: {
        SqlValidator: SqlValidator;
    };
    shared: SqlSharedServices;
};
export type SqlAddedSharedServices = {
    workspace: {
        WorkspaceManager: SqlWorkspaceManager;
        ContainerManager: SqlContainerManager;
    };
};
export declare const SqlSharedModule: Module<SqlSharedServices, DeepPartial<SqlSharedServices>>;
/**
 * Union of Langium default services and your custom services - use this as constructor parameter
 * of custom service classes.
 */
export type SqlServices = LangiumServices & SqlAddedServices;
export type SqlSharedServices = LangiumSharedServices & SqlAddedSharedServices;
/**
 * Dependency injection module that overrides Langium default services and contributes the
 * declared custom services. The Langium defaults can be partially specified to override only
 * selected services, while the custom services must be fully specified.
 */
export declare const SqlModule: Module<SqlServices, DeepPartial<SqlServices>>;
export interface SqlSharedModuleContext extends DefaultSharedModuleContext {
    module?: Module<SqlServices, DeepPartial<SqlServices>>;
    sharedModule?: Module<SqlSharedServices, DeepPartial<SqlSharedServices>>;
}
/**
 * Create the full set of services required by Langium.
 *
 * First inject the shared services by merging two modules:
 *  - Langium default shared services
 *  - Services generated by langium-cli
 *
 * Then inject the language-specific services by merging three modules:
 *  - Langium default language-specific services
 *  - Services generated by langium-cli
 *  - Services specified in this file
 *
 * @param context Optional module context with the LSP connection
 * @returns An object wrapping the shared services and the language-specific services
 */
export declare function createSqlServices(context: SqlSharedModuleContext): {
    shared: SqlSharedServices;
    Sql: SqlServices;
};
