"use strict";
/******************************************************************************
 * Copyright 2022-2023 TypeFox GmbH
 * This program and the accompanying materials are made available under the
 * terms of the MIT License, which is available in the project root.
 ******************************************************************************/
Object.defineProperty(exports, "__esModule", { value: true });
exports.SqlScopeComputation = void 0;
const langium_1 = require("langium");
const ast_1 = require("./generated/ast");
class SqlScopeComputation extends langium_1.DefaultScopeComputation {
    exportNode(node, exports, document) {
        if ((0, ast_1.isCatalogDefinition)(node) || (0, ast_1.isSchemaDefinition)(node) || (0, ast_1.isTableDefinition)(node) || (0, ast_1.isFunctionDefinition)(node)) {
            if ((0, ast_1.isCatalogDefinition)(node)) {
                super.exportNode(node, exports, document);
            }
            else {
                const reference = node.reference;
                if (reference && !reference.previous) {
                    // Only export the node to the global context if it is not scoped to another declaration
                    super.exportNode(node, exports, document);
                }
            }
        }
    }
    processNode(node, document, scopes) {
        const container = node.$container;
        if ((0, ast_1.isWithClause)(container)) {
            const selectStatement = container.$container;
            // A table used in a `WITH` clause needs to be visible to the root select statement
            for (const cte of container.ctes) {
                const name = this.nameProvider.getName(cte);
                if (name) {
                    scopes.add(selectStatement, this.descriptions.createDescription(cte, name, document));
                }
            }
        }
        else if ((0, ast_1.isDefinition)(container)) {
            // Definitions come from the global scope
            // They are not added to the local scope
            return;
        }
        else {
            super.processNode(node, document, scopes);
        }
    }
}
exports.SqlScopeComputation = SqlScopeComputation;
//# sourceMappingURL=sql-scope-computation.js.map