/******************************************************************************
 * Copyright 2022-2023 TypeFox GmbH
 * This program and the accompanying materials are made available under the
 * terms of the MIT License, which is available in the project root.
 ******************************************************************************/
import { AstNode, AstNodeDescriptionProvider, AstNodeLocator, DefaultScopeProvider, LangiumDocuments, NamedAstNode, Reference, ReferenceInfo, Scope } from "langium";
import { SqlContainerManager } from "./sql-container-manager";
import { SqlServices } from "./sql-module";
/**
 * Returns a type to have only properties names (!) of a type T whose property value is of a certain type K.
 */
type ExtractKeysOfValueType<T, K> = {
    [I in keyof T]: T[I] extends K ? I : never;
}[keyof T];
/**
 * Returns the property names (!) of an AstNode that are cross-references.
 * Meant to be used during cross-reference resolution in combination with `assertUnreachable(context.property)`.
 */
export type CrossReferencesOfAstNodeType<N extends AstNode> = (ExtractKeysOfValueType<N, Reference | undefined> | ExtractKeysOfValueType<N, Array<Reference | undefined> | undefined>) & {};
/**
 * Represents the enumeration-like type, that lists all AstNode types of your grammar.
 */
export type AstTypeList<T> = Record<keyof T, AstNode>;
/**
 * Returns all types that contain cross-references, A is meant to be the interface `XXXAstType` fromm your generated `ast.ts` file.
 * Meant to be used during cross-reference resolution in combination with `assertUnreachable(context.container)`.
 */
export type AstNodeTypesWithCrossReferences<A extends AstTypeList<A>> = {
    [T in keyof A]: CrossReferencesOfAstNodeType<A[T]> extends never ? never : A[T];
}[keyof A];
export declare class SqlScopeProvider extends DefaultScopeProvider {
    protected readonly astNodeDescriptionProvider: AstNodeDescriptionProvider;
    protected readonly astNodeLocator: AstNodeLocator;
    protected readonly langiumDocuments: LangiumDocuments;
    protected readonly containerManager: SqlContainerManager;
    constructor(services: SqlServices);
    getScope(context: ReferenceInfo): Scope;
    private getTableVariablesForSelectStatementRecursively;
    private getTableVariablesForSelectStatement;
    getGlobalScope(nodeType: string, _context: ReferenceInfo): Scope;
    protected unpackFromDescriptions<N extends NamedAstNode>(scope: Scope): N[];
    protected packToDescriptions<N extends NamedAstNode>(nodes: N[]): Scope;
    private streamColumnDescriptors;
    private streamColumnDefinitions;
    private newCaseInsensitiveScope;
}
export {};
