/******************************************************************************
 * Copyright 2022-2023 TypeFox GmbH
 * This program and the accompanying materials are made available under the
 * terms of the MIT License, which is available in the project root.
 ******************************************************************************/
import { AstNode } from "langium";
import { Expression, SelectTableExpression } from "./generated/ast";
import { RowTypeDescriptor, TypeDescriptor } from "./sql-type-descriptors";
import * as DataTypes from "./sql-data-types";
import { SqlServices } from "./sql-module";
export interface TypeComputer {
    computeType(node: AstNode): TypeDescriptor | undefined;
    computeTypeOfSelectStatement(selectStatement: SelectTableExpression): RowTypeDescriptor;
    computeTypeOfNumericLiteral(text: string): TypeDescriptor | undefined;
}
export declare class SqlTypeComputer implements TypeComputer {
    protected dataTypes: DataTypes.DialectTypes;
    constructor(services: SqlServices);
    computeType(node: AstNode): TypeDescriptor | undefined;
    protected computeTypeOfExpression(node: Expression): TypeDescriptor | undefined;
    computeTypeOfSelectStatement(selectStatement: SelectTableExpression): RowTypeDescriptor;
    private computeTypeOfDataType;
    computeTypeOfNumericLiteral(text: string): TypeDescriptor | undefined;
    private computeTypeOfBinaryOperation;
    private computeTypeOfUnaryOperation;
}
