/******************************************************************************
 * Copyright 2022-2023 TypeFox GmbH
 * This program and the accompanying materials are made available under the
 * terms of the MIT License, which is available in the project root.
 ******************************************************************************/
export type NumberTypeDescriptorDiscriminator = "integer" | "real";
export type TypeDescriptorDiscriminator = "boolean" | NumberTypeDescriptorDiscriminator | "text" | "row" | 'enum' | 'datetime' | 'null' | 'array' | 'blob' | 'unknown';
export declare function isTypeANull(type: TypeDescriptor): type is NullTypeDescriptor;
export declare function isTypeABoolean(type: TypeDescriptor): type is BooleanTypeDesciptor;
export declare function isTypeANumber(type: TypeDescriptor): type is NumberTypeDescriptor;
export declare function isTypeAReal(type: TypeDescriptor): type is RealTypeDescriptor;
export declare function isTypeADateTime(type: TypeDescriptor): type is DateTimeTypeDescriptor;
export declare function isTypeAnInteger(type: TypeDescriptor): type is IntegerTypeDescriptor;
export declare function isTypeARow(type: TypeDescriptor): type is IntegerTypeDescriptor;
export declare function isTypeAnEnum(type: TypeDescriptor): type is EnumTypeDescriptor;
export declare function isTypeABlob(type: TypeDescriptor): type is BlobTypeDescriptor;
export declare function isTypeAText(type: TypeDescriptor): type is CharTypeDescriptor;
export interface TypeDescriptorBase {
    discriminator: TypeDescriptorDiscriminator;
    arguments?: TypeArgument[];
}
export interface RowTypeDescriptor extends TypeDescriptorBase {
    discriminator: "row";
    columnTypes: ColumnTypeDescriptor[];
}
export interface ColumnTypeDescriptor {
    name: string | undefined;
    type: TypeDescriptor;
}
export interface RealTypeDescriptor extends TypeDescriptorBase {
    discriminator: "real";
}
export interface EnumTypeDescriptor extends TypeDescriptorBase {
    discriminator: "enum";
    members: string[];
}
export interface IntegerTypeDescriptor extends TypeDescriptorBase {
    discriminator: "integer";
}
export interface BooleanTypeDesciptor extends TypeDescriptorBase {
    discriminator: "boolean";
}
export interface CharTypeDescriptor extends TypeDescriptorBase {
    discriminator: "text";
    length: number;
}
export interface NullTypeDescriptor extends TypeDescriptorBase {
    discriminator: "null";
}
export interface ArrayTypeDescriptor extends TypeDescriptorBase {
    discriminator: "array";
    elementType: TypeDescriptor;
}
export interface DateTimeTypeDescriptor extends TypeDescriptorBase {
    discriminator: "datetime";
}
export interface BlobTypeDescriptor extends TypeDescriptorBase {
    discriminator: "blob";
}
export interface UnknownTypeDescriptor extends TypeDescriptorBase {
    discriminator: "unknown";
}
export type TypeArgument = string | number;
export type TextualTypeDescriptor = CharTypeDescriptor;
export type NumberTypeDescriptor = IntegerTypeDescriptor | RealTypeDescriptor;
export type TypeDescriptor = UnknownTypeDescriptor | BlobTypeDescriptor | ArrayTypeDescriptor | NullTypeDescriptor | BooleanTypeDesciptor | NumberTypeDescriptor | TextualTypeDescriptor | RowTypeDescriptor | EnumTypeDescriptor | DateTimeTypeDescriptor;
export type TypeSet = Record<string, TypeDescriptor | ((args: TypeArgument[]) => TypeDescriptor)>;
export declare const Types: {
    Unknown: UnknownTypeDescriptor;
    Null: NullTypeDescriptor;
    ArrayOf(elementType: TypeDescriptor): TypeDescriptor;
    Boolean: TypeDescriptor;
    Blob: TypeDescriptor;
    Integer: TypeDescriptor;
    Real: TypeDescriptor;
    DateTime: TypeDescriptor;
    Char(length?: number): TypeDescriptor;
    Enum(members: TypeArgument[]): TypeDescriptor;
};
export declare function areTypesEqual(lhs: TypeDescriptor, rhs: TypeDescriptor): boolean;
