"use strict";
/******************************************************************************
 * Copyright 2022-2023 TypeFox GmbH
 * This program and the accompanying materials are made available under the
 * terms of the MIT License, which is available in the project root.
 ******************************************************************************/
Object.defineProperty(exports, "__esModule", { value: true });
exports.areTypesEqual = exports.Types = exports.isTypeAText = exports.isTypeABlob = exports.isTypeAnEnum = exports.isTypeARow = exports.isTypeAnInteger = exports.isTypeADateTime = exports.isTypeAReal = exports.isTypeANumber = exports.isTypeABoolean = exports.isTypeANull = void 0;
const tslib_1 = require("tslib");
const lodash_1 = tslib_1.__importDefault(require("lodash"));
function isTypeANull(type) {
    return type.discriminator === "null";
}
exports.isTypeANull = isTypeANull;
function isTypeABoolean(type) {
    return type.discriminator === "boolean";
}
exports.isTypeABoolean = isTypeABoolean;
function isTypeANumber(type) {
    return [
        "integer",
        "real",
    ].includes(type.discriminator);
}
exports.isTypeANumber = isTypeANumber;
function isTypeAReal(type) {
    return type.discriminator === "real";
}
exports.isTypeAReal = isTypeAReal;
function isTypeADateTime(type) {
    return type.discriminator === "datetime";
}
exports.isTypeADateTime = isTypeADateTime;
function isTypeAnInteger(type) {
    return type.discriminator === "integer";
}
exports.isTypeAnInteger = isTypeAnInteger;
function isTypeARow(type) {
    return type.discriminator === "row";
}
exports.isTypeARow = isTypeARow;
function isTypeAnEnum(type) {
    return type.discriminator === "enum";
}
exports.isTypeAnEnum = isTypeAnEnum;
function isTypeABlob(type) {
    return type.discriminator === "blob";
}
exports.isTypeABlob = isTypeABlob;
function isTypeAText(type) {
    return [
        "text",
    ].includes(type.discriminator);
}
exports.isTypeAText = isTypeAText;
exports.Types = {
    Unknown: {
        discriminator: 'unknown'
    },
    Null: {
        discriminator: 'null',
    },
    ArrayOf(elementType) {
        return {
            discriminator: 'array',
            elementType
        };
    },
    Boolean: {
        discriminator: 'boolean'
    },
    Blob: {
        discriminator: 'blob'
    },
    Integer: {
        discriminator: 'integer'
    },
    Real: {
        discriminator: 'real'
    },
    DateTime: {
        discriminator: 'datetime'
    },
    Char(length = 100) {
        return {
            discriminator: 'text',
            length
        };
    },
    Enum(members) {
        return { discriminator: 'enum', members: members.filter(e => typeof e === 'string') };
    }
};
function areTypesEqual(lhs, rhs) {
    return lodash_1.default.isEqual(lhs, rhs);
}
exports.areTypesEqual = areTypesEqual;
//# sourceMappingURL=sql-type-descriptors.js.map