"use strict";
/******************************************************************************
 * Copyright 2022-2023 TypeFox GmbH
 * This program and the accompanying materials are made available under the
 * terms of the MIT License, which is available in the project root.
 ******************************************************************************/
Object.defineProperty(exports, "__esModule", { value: true });
exports.BinaryOperators = exports.UnaryOperators = void 0;
const tslib_1 = require("tslib");
const lodash_1 = tslib_1.__importDefault(require("lodash"));
const sql_type_descriptors_1 = require("./sql-type-descriptors");
const IntegerReturnsInteger = {
    operandType: sql_type_descriptors_1.Types.Integer,
    returnType: sql_type_descriptors_1.Types.Integer
};
const RealReturnsReal = {
    operandType: sql_type_descriptors_1.Types.Real,
    returnType: sql_type_descriptors_1.Types.Real
};
const BooleanReturnsBoolean = {
    operandType: sql_type_descriptors_1.Types.Boolean,
    returnType: sql_type_descriptors_1.Types.Boolean
};
const ReversedUnaryOperators = new Map();
ReversedUnaryOperators.set(IntegerReturnsInteger, ['+', '-']);
ReversedUnaryOperators.set(RealReturnsReal, ['+', '-']);
ReversedUnaryOperators.set(BooleanReturnsBoolean, ['NOT']);
const unaries = [...ReversedUnaryOperators.entries()].flatMap(([descr, operators]) => {
    return operators.map(op => [op, descr]);
});
function emptUnaryTable() {
    const result = {};
    const indices = ["+", "-", "NOT"];
    indices.forEach(op => result[op] = []);
    return result;
}
exports.UnaryOperators = Object.entries(lodash_1.default.groupBy(unaries, ([op]) => op))
    .reduce((lhs, rhs) => {
    const key = rhs[0];
    lhs[key] = lhs[key].concat(rhs[1].map(descr => descr[1]));
    return lhs;
}, emptUnaryTable());
const IntegerIntegerReturnsInteger = {
    left: sql_type_descriptors_1.Types.Integer,
    right: sql_type_descriptors_1.Types.Integer,
    returnType: sql_type_descriptors_1.Types.Integer
};
const RealRealReturnsReal = {
    left: sql_type_descriptors_1.Types.Real,
    right: sql_type_descriptors_1.Types.Real,
    returnType: sql_type_descriptors_1.Types.Real
};
const IntegerIntegerReturnsBoolean = {
    left: sql_type_descriptors_1.Types.Integer,
    right: sql_type_descriptors_1.Types.Integer,
    returnType: sql_type_descriptors_1.Types.Boolean
};
const RealRealReturnsBoolean = {
    left: sql_type_descriptors_1.Types.Real,
    right: sql_type_descriptors_1.Types.Real,
    returnType: sql_type_descriptors_1.Types.Boolean
};
const BooleanBooleanReturnsBoolean = {
    left: sql_type_descriptors_1.Types.Boolean,
    right: sql_type_descriptors_1.Types.Boolean,
    returnType: sql_type_descriptors_1.Types.Boolean
};
const CharCharReturnsBoolean = {
    left: sql_type_descriptors_1.Types.Char(),
    right: sql_type_descriptors_1.Types.Char(),
    returnType: sql_type_descriptors_1.Types.Boolean
};
const CharCharReturnsChar = {
    left: sql_type_descriptors_1.Types.Char(),
    right: sql_type_descriptors_1.Types.Char(),
    returnType: sql_type_descriptors_1.Types.Char()
};
const CharCharReturnsReal = {
    left: sql_type_descriptors_1.Types.Char(),
    right: sql_type_descriptors_1.Types.Char(),
    returnType: sql_type_descriptors_1.Types.Real
};
const ReversedBinaryOperators = new Map();
ReversedBinaryOperators.set(IntegerIntegerReturnsInteger, ["%", "*", "+", "-", "/"]);
ReversedBinaryOperators.set(RealRealReturnsReal, ["%", "*", "+", "-", "/"]);
ReversedBinaryOperators.set(IntegerIntegerReturnsBoolean, ["<", "<=", "<>", "=", ">", ">="]);
ReversedBinaryOperators.set(RealRealReturnsBoolean, ["<", "<=", "<>", "=", ">", ">="]);
ReversedBinaryOperators.set(CharCharReturnsBoolean, ["<", "<=", "<>", "=", ">", ">=", "LIKE"]);
ReversedBinaryOperators.set(BooleanBooleanReturnsBoolean, ["<", "<=", "<>", "=", ">", ">=", "AND", "OR"]);
ReversedBinaryOperators.set(CharCharReturnsChar, ['||', 'LIKE', '::$', '::']);
ReversedBinaryOperators.set(CharCharReturnsReal, ['::%']);
const flatMap = [...ReversedBinaryOperators.entries()].flatMap(([descr, operators]) => {
    return operators.map(op => [op, descr]);
});
function emptyBinaryTable() {
    const result = {};
    const indices = ["%", "*", "+", "-", "/", "<", "<=", "<>", "=", ">", ">=", "AND", "OR", "||", "IS", "LIKE", "IN", "::", "::$", "::%"];
    indices.forEach(op => result[op] = []);
    return result;
}
exports.BinaryOperators = Object.entries(lodash_1.default.groupBy(flatMap, ([op]) => op))
    .reduce((lhs, rhs) => {
    const key = rhs[0];
    lhs[key] = lhs[key].concat(rhs[1].map(descr => descr[1]));
    return lhs;
}, emptyBinaryTable());
//# sourceMappingURL=sql-type-operators.js.map