/******************************************************************************
 * Copyright 2022-2023 TypeFox GmbH
 * This program and the accompanying materials are made available under the
 * terms of the MIT License, which is available in the project root.
 ******************************************************************************/
import { ValidationAcceptor, ValidationRegistry } from "langium";
import * as ast from "./generated/ast";
import type { SqlServices } from "./sql-module";
export declare class SqlValidationRegistry extends ValidationRegistry {
    constructor(services: SqlServices);
}
export declare class SqlValidator {
    private typeComputer;
    private dataTypes;
    constructor(services: SqlServices);
    checkBinaryTableExpressionMatches(expr: ast.BinaryTableExpression, accept: ValidationAcceptor): void;
    checkIfExpressionHasType(expr: ast.Expression, accept: ValidationAcceptor): void;
    checkWhereIsBoolean(clause: ast.WhereClause, accept: ValidationAcceptor): void;
    checkHavingIsBoolean(clause: ast.HavingClause, accept: ValidationAcceptor): void;
    checkBinaryExpressionType(expr: ast.BinaryExpression, accept: ValidationAcceptor): void;
    checkUnaryExpressionType(expr: ast.UnaryExpression, accept: ValidationAcceptor): void;
    checkVariableNamesAreUnique(query: ast.SimpleSelectStatement, accept: ValidationAcceptor): void;
    checkIntegerLiteralIsWholeNumber(literal: ast.NumberLiteral, accept: ValidationAcceptor): void;
    checkIfSelectStatementWithAllStarSelectItemHasAtLeastOneTableSource(selectStatement: ast.SimpleSelectStatement, accept: ValidationAcceptor): void;
    checkIfTableDefinitionHasAtLeastOneColumn(tableDefinition: ast.TableDefinition, accept: ValidationAcceptor): void;
    checkIfReferencePointsToCorrectParent(referenceDefinition: ast.ReferenceDefinition, accept: ValidationAcceptor): void;
    protected checkReferenceParent(globalReference: ast.GlobalReference, accept: ValidationAcceptor): void;
    checkIfSubQuerySelectsExactlyOneValue(subQueryExpression: ast.SubQueryExpression, accept: ValidationAcceptor): void;
    checkFunctionCallTarget(functionCall: ast.FunctionCall, accept: ValidationAcceptor): void;
    checkTableSourceItemTarget(tableSourceItem: ast.TableSourceItem, accept: ValidationAcceptor): void;
    checkConstraintTarget(constraintDefinition: ast.ConstraintDefinition, accept: ValidationAcceptor): void;
    checkIfKnownDataType(dataType: ast.DataType, accept: ValidationAcceptor): void;
}
